pub struct CompressionWriter<W: Write + 'static> { /* private fields */ }Expand description
A writer that compresses data as it is written.
Implementations
Sourceimpl<W: Write + 'static> CompressionWriter<W>
impl<W: Write + 'static> CompressionWriter<W>
Sourcepub fn new(writer: W, format: CompressionFormat) -> Result<Self>
pub fn new(writer: W, format: CompressionFormat) -> Result<Self>
Create a compression writer with the specified format.
Sourcepub fn with_level(
writer: W,
format: CompressionFormat,
level: Option<u32>,
) -> Result<Self>
pub fn with_level( writer: W, format: CompressionFormat, level: Option<u32>, ) -> Result<Self>
Create a compression writer with a specific compression level.
Sourcepub fn format(&self) -> CompressionFormat
pub fn format(&self) -> CompressionFormat
Get the compression format being used.